# django-ok-payparts

Simple E-Sputnik REST client library for Python.

## Installation

Install with pip:

```shell
$ pip install ok-esputnik
```

### Usage

See a list of examples [here](https://github.com/LowerDeez/ok-esputnik/blob/master/esputnik/examples/cases.py)